#
# camera/__init__.py
#
# This file is part of the Python package to handle Camera data (CAMPP).
#
# Copyright (c) 2009-2012, Universiteit Leiden
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# - Redistributions of source code must retain the above copyright notice,
#   this list of conditions and the following disclaimer.
# - Redistributions in binary form must reproduce the above copyright notice,
#   this list of conditions and the following disclaimer in the documentation
#   and/or other materials provided with the distribution.
# - Neither the name of Universiteit Leiden nor the names of its contributors
#   may be used to endorse or promote products derived from this software
#   without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS
# BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
# THE POSSIBILITY OF SUCH DAMAGE.

#
# Authors: Martin Moene (original)
#
# $Id: __init__.py 649 2012-02-27 13:41:59Z moene $
#

"""Python package to do Camera-related processing.

Camera is the control and analysis application for the Leiden Probe Microscopy
Scanning Tunneling Microscope (STM) and for the Atomic Force Microscope (AFM).
Camera is the acronym for Computer Aided Measurement Environment for Realtime
Atomic imaging.

STM and AFM are collectively called Scanning Probe Microscopy (SPM). For an
introduction to this, see the "Principle of Scanning probe microscopy" at:
   http://www.physics.leidenuniv.nl/sections/cm/ip/group/Principle_of_SPM.htm

Camera is a Windows application for the Microsoft Windows NT/2000/XP platform.
It is created with Microsoft Visual C++ 6.0 (MSVC6) and it uses the Microsoft
Foundation Classes (MFC).

Subpackages:
- camera.formats: access to various Camera data formats

Modules:
- none

Weblinks:
- IP: Interface Physics, http://www.physics.leidenuniv.nl/sections/cm/ip/
- LPM: Leiden Probe Microscopy, http://www.leidenprobemicroscopy.com/

See also http://www.physics.leidenuniv.nl/sections/cm/ip/Internal/Camera/Camera-MainPage.html

"""

__all__ = []

__version_info__ = ( 0, 5, 0, 'final', 0 )
__version_date__ = '$Date: 2012-02-27 14:41:59 +0100 (Mon, 27 Feb 2012) $'
__version__      = '$Revision: 649 $'
__author__       = 'Martin Moene <m.j.moene@eld.physics.LeidenUniv.nl>'
__url__          = 'http://www.physics.leidenuniv.nl/sections/cm/ip/Internal/Camera/Camera-MainPage.html'


def _versionString():
   """Version string such as '1.2.3'"""
   return '.'.join(map(str, __version_info__[0:3]))


def _versionState():
   """Version state such as 'alpha', 'beta', 'final'"""
   return __version_info__[3]


def _versionDate():
   """Version date such as 'Thu, 10 Jun 2010'"""
   return __version_date__[34:-3]

#
# end of file
#
